# IHC_PMS_Lib Wrappers

Python wrappers for INHECO ODTC and SCILA libraries by INHECO GmbH.  
The libraries require .Net Framework 4.8 (Windows) or Mono Framework 6.12.0 (Linux/Mac).  
Architectures supported: x86, x64  

## Install
Download IHC_PMS_Lib for ODTC or SCILA (no public download) package and unpack.  
Linux/Mac needs mono-complete package from https://www.mono-project.com/download/stable/  
  
Ubuntu  
$ sudo apt install python3-pip python3-venv  
$ python3 -m pip install --upgrade pip setuptools wheel  
$ python3 -m pip ihc_pms_lib-wrappers  
